@@ -90,7 +90,7 @@ class DefaultWindow(QMainWindow):
     def rebootBtn_Clicked(self):
         import os
         os.system("kill -9 `ps -ef|grep location/number|grep -v \"grep\"|awk '{print $1}'`")
-        os.system("python numberlocation.py &")
+        os.system("python /home/user/apps/numberlocation/numberlocation.py &")
         
         self.show_notice("后台进程重新启动成功！")
         
